@@ -16,7 +16,8 @@
 #define AWS_HAVE_GCC_INLINE_ASM
 /* #undef AWS_HAVE_MSVC_MULX */
 #define AWS_HAVE_POSIX_LARGE_FILE_SUPPORT
-#define AWS_HAVE_EXECINFO
+/* #undef AWS_HAVE_EXECINFO */
 /* #undef AWS_HAVE_WINAPI_DESKTOP */
+#define AWS_HAVE_LINUX_IF_LINK_H
 
 #endif
